DomainLayerGenerator class

Constructors

DomainLayerGenerator({required Logger logger})

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → Logger
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate({required String basePath, required FeatureSchema schema, bool updateOnly = false}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited