ApiServiceTemplate class

A template generator for the API Service (DataSource) layer.

It generates a Dio/Retrofit compatible interface based on the feature schema.

Constructors

ApiServiceTemplate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate(FeatureSchema schema) String
Generates the complete source code for the API Service file.
generateRequestMethod(FunctionDef func) String
generateSingleFunctionModelImports(FunctionDef f) Set<String>
generateUrlConstant(FunctionDef func) String