DITemplate class

A template generator for the Dependency Injection (DI) layer.

It generates the registration logic for DataSources, Repositories, UseCases, and Cubits.

Constructors

DITemplate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generate(FeatureSchema schema) String
Generates the complete source code for the feature's DI file.