ModelGenerator class

Constructors

ModelGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateRequestModel(FunctionDef function, {String strategy = 'empty'}) String
Generate request model class from schema
generateResponseModel(FunctionDef function, {String strategy = 'empty'}) String
Generate response model class from schema
getBaseResponseModelType(FunctionDef function) String
Get base response model type name (without List)
getRequestModelType(FunctionDef function) String
Get request model type name
getResponseModelType(FunctionDef function) String
Get response model type name with List handling
isMagic(dynamic value) bool