FeatureSchema class
Represents the schema for a feature to be generated.
Constructors
-
FeatureSchema({required String name, required List<
FunctionDef> functions, required GlobalConfig globalConfig}) - Creates a FeatureSchema instance.
-
FeatureSchema.fromJson(Map<
String, dynamic> json, GlobalConfig global) -
Creates a FeatureSchema from a JSON map and global config.
factory
Properties
-
functions
→ List<
FunctionDef> -
The list of API functions associated with the feature.
final
- globalConfig → GlobalConfig
-
The global configuration to use for generation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the feature.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isValid(
) → bool - Validates the schema.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited