GlobalConfig class
Represents the global configuration for the CLI tool.
Constructors
-
GlobalConfig({Map<
String, String> imports = const {}, Map<String, String> config = const {}}) - Creates a GlobalConfig instance.
-
GlobalConfig.fromJson(Map<
String, dynamic> json) -
Creates a GlobalConfig from a JSON map.
factory
Properties
-
config
→ Map<
String, String> -
A map of configuration options (e.g., locator name).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imports
→ Map<
String, String> -
A map of shared imports (e.g., DataState, UseCase).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the GlobalConfig to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited