FileWriter class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createDartFile(
{required String dirPath, required String fileName, required String content}) → Future< void> -
injectToClass(
{required String filePath, required String newContent, String? anchor}) → Future< void> -
injectTopLevel(
{required String filePath, required String newContent}) → Future< void> -
toCamelCase(
String input) → String -
toConstName(
String input) → String -
toLowerCamelCase(
String input) → String -
toSnakeCase(
String input) → String